@@ -528,19 +528,15 @@ void StoredSession::validate(const Application& app, const char* client_addr, ti
 
         // Versioned read, since we already have the data in hand if it's current.
         string record;
-        time_t lastAccess = 0;
+        time_t lastAccess;
         int curver = m_obj["version"].integer();
         int ver = m_cache->m_storage->readText(getID(), "session", &record, &lastAccess, curver);
         if (ver == 0) {
-            m_cache->m_log.info("session (ID: %s) no longer in storage", getID());
+            m_cache->m_log.warn("unsuccessful versioned read of session (ID: %s), cache out of sync?", getID());
             throw RetryableProfileException("Your session has expired, and you must re-authenticate.");
         }
 
         if (timeout) {
-            if (lastAccess == 0) {
-                m_cache->m_log.error("session (ID: %s) did not report time of last access", getID());
-                throw RetryableProfileException("Your session has expired, and you must re-authenticate.");
-            }
             // Adjust for expiration to recover last access time and check timeout.
             unsigned long cacheTimeout = m_cache->getCacheTimeout(app);
             lastAccess -= cacheTimeout;
@@ -623,7 +619,7 @@ void StoredSession::validate(const Application& app, const char* client_addr, ti
                         throw IOException("Unable to update stored session, exceeded retry limit.");
                     }
                     m_cache->m_log.warn("storage service indicates the record is out of sync, updating with a fresh copy...");
-                    ver = m_cache->m_storage->readText(getID(), "session", &record);
+                    ver = m_cache->m_storage->readText(getID(), "session", &record, nullptr);
                     if (!ver) {
                         m_cache->m_log.error("readText failed on StorageService for session (%s)", getID());
                         throw IOException("Unable to read back stored session.");
@@ -716,7 +712,7 @@ void StoredSession::addAttributes(const vector<Attribute*>& attributes)
                 throw IOException("Unable to update stored session, exceeded retry limit.");
             }
             m_cache->m_log.warn("storage service indicates the record is out of sync, updating with a fresh copy...");
-            ver = m_cache->m_storage->readText(getID(), "session", &record);
+            ver = m_cache->m_storage->readText(getID(), "session", &record, nullptr);
             if (!ver) {
                 m_cache->m_log.error("readText failed on StorageService for session (%s)", getID());
                 throw IOException("Unable to read back stored session.");
@@ -753,7 +749,7 @@ const Assertion* StoredSession::getAssertion(const char* id) const
         return i->second.get();
 
     string tokenstr;
-    if (!m_cache->m_storage->readText(getID(), id, &tokenstr))
+    if (!m_cache->m_storage->readText(getID(), id, &tokenstr, nullptr))
         throw FatalProfileException("Assertion not found in cache.");
 
     // Parse and bind the document into an XMLObject.
@@ -790,8 +786,8 @@ void StoredSession::addAssertion(Assertion* assertion)
 
     m_cache->m_log.debug("adding assertion (%s) to session (%s)", id.get(), getID());
 
-    time_t exp = 0;
-    if (!m_cache->m_storage->readText(getID(), "session", nullptr, &exp) || exp == 0)
+    time_t exp;
+    if (!m_cache->m_storage->readText(getID(), "session", nullptr, &exp))
         throw IOException("Unable to load expiration time for stored session.");
 
     ostringstream tokenstr;
@@ -839,7 +835,7 @@ void StoredSession::addAssertion(Assertion* assertion)
                 throw IOException("Unable to update stored session, exceeded retry limit.");
             }
             m_cache->m_log.warn("storage service indicates the record is out of sync, updating with a fresh copy...");
-            ver = m_cache->m_storage->readText(getID(), "session", &record);
+            ver = m_cache->m_storage->readText(getID(), "session", &record, nullptr);
             if (!ver) {
                 m_cache->m_log.error("readText failed on StorageService for session (%s)", getID());
                 m_cache->m_storage->deleteText(getID(), id.get());
@@ -1065,7 +1061,7 @@ void SSCache::insert(const char* key, time_t expires, const char* name, const ch
 
     // Since we can't guarantee uniqueness, check for an existing record.
     string record;
-    time_t recordexp = 0;
+    time_t recordexp;
     int ver = m_storage_lite->readText("NameID", name, &record, &recordexp);
     if (ver > 0) {
         // Existing record, so we need to unmarshall it.
@@ -1627,17 +1623,12 @@ Session* SSCache::find(const Application& app, const char* key, const char* clie
             m_log.debug("searching for session (%s)", key);
 
             DDF obj;
-            time_t lastAccess = 0;
+            time_t lastAccess;
             string record;
             int ver = m_storage->readText(key, "session", &record, &lastAccess);
             if (!ver)
                 return nullptr;
 
-            if (0 == lastAccess) {
-                m_log.error("session (ID: %s) did not report time of last access", key);
-                throw RetryableProfileException("Your session has expired, and you must re-authenticate.");
-            }
-
             m_log.debug("reconstituting session and checking validity");
 
             istringstream in(record);
@@ -1869,16 +1860,10 @@ void* SSCache::cleanup_fn(void* p)
 
     // Load our configuration details...
     static const XMLCh cleanupInterval[] = UNICODE_LITERAL_15(c,l,e,a,n,u,p,I,n,t,e,r,v,a,l);
-    const XMLCh* tag = pcache->m_root ? pcache->m_root->getAttributeNS(nullptr, cleanupInterval) : nullptr;
+    const XMLCh* tag=pcache->m_root ? pcache->m_root->getAttributeNS(nullptr, cleanupInterval) : nullptr;
     int rerun_timer = 900;
     if (tag && *tag) {
-        try {
-            rerun_timer = XMLString::parseInt(tag);
-        }
-        catch (XMLException&) {
-            pcache->m_log.error("cleanupInterval setting was not a numeric value");
-            rerun_timer = 0;
-        }
+        rerun_timer = XMLString::parseInt(tag);
         if (rerun_timer <= 0)
             rerun_timer = 900;
     }
@@ -1950,7 +1935,7 @@ void SSCache::receive(DDF& in, ostream& out)
 
         // Do an unversioned read.
         string record;
-        time_t lastAccess = 0;
+        time_t lastAccess;
         if (!m_storage->readText(key, "session", &record, &lastAccess)) {
             m_log.debug("session not found in cache (%s)", key);
             DDF ret(nullptr);
@@ -1958,10 +1943,6 @@ void SSCache::receive(DDF& in, ostream& out)
             out << ret;
             return;
         }
-        else if (lastAccess == 0) {
-            m_log.error("session (ID: %s) did not report time of last access", key);
-            throw RetryableProfileException("Your session has expired, and you must re-authenticate.");
-        }
 
         // Adjust for expiration to recover last access time and check timeout.
         unsigned long cacheTimeout = getCacheTimeout(*app);
@@ -2008,15 +1989,11 @@ void SSCache::receive(DDF& in, ostream& out)
 
         // Do a read. May be unversioned if we need to bind a new client address.
         string record;
-        time_t lastAccess = 0;
+        time_t lastAccess;
         int curver = in["version"].integer();
         int ver = m_storage->readText(key, "session", &record, &lastAccess, client_addr ? 0 : curver);
         if (ver == 0) {
-            m_log.info("session (ID: %s) no longer in storage", key);
-            throw RetryableProfileException("Your session has expired, and you must re-authenticate.");
-        }
-        else if (lastAccess == 0) {
-            m_log.error("session (ID: %s) did not report time of last access", key);
+            m_log.warn("unsuccessful read of session (ID: %s), caches out of sync?", key);
             throw RetryableProfileException("Your session has expired, and you must re-authenticate.");
         }
 
